using System;
using System.Collections.Generic;
using System.IO;
using Syncfusion.DocIO.DLS;
using Syncfusion.DocIO;
using System.Text.RegularExpressions;

namespace DocIO
{
    public class Merger
    {
        public Merger()
        {
        }

        private WordDocument WDocument { get; set; }

        public void OpenWordDocument(string pDocumentPath)
        {
            if (!File.Exists(pDocumentPath))
                throw new Exception("Le fichier n'existe pas");
            Stream inputStream = new FileStream(pDocumentPath, FileMode.Open);
            WDocument = new WordDocument();
            WDocument.Open(inputStream, FormatType.Doc);
            inputStream.Close();
            inputStream.Dispose();
        }

        public string[] GetFieldNames()
        {
            return WDocument.MailMerge.GetMergeFieldNames();
        }

        public void MergeFields(string[] pFieldNames, string[] pFieldValues)
        {
            WDocument.MailMerge.Execute(pFieldNames, pFieldValues);
        }

        public void MergeFields(Dictionary<string, string> pDictionary)
        {
            var fields = new List<string>();
            var values = new List<string>();
            fields.AddRange(pDictionary.Keys);
            values.AddRange(pDictionary.Values);
            WDocument.MailMerge.Execute(fields.ToArray(), values.ToArray());
        }

        public void MergeImage(string sFile, string sBalise)
        {
            var imageBytes = File.ReadAllBytes(sFile);
            WordDocument imageDoc = new WordDocument();
            imageDoc.AddSection();
            imageDoc.Sections[0].AddParagraph().AppendPicture(imageBytes);

            if (imageBytes != null)
            {
                TextSelection ts = null;
                Regex pattern = new Regex(sBalise);
                ts = WDocument.Find(pattern);

                if (ts != null)
                {
                    WDocument.ReplaceFirst = true;
                    WDocument.Replace(pattern, imageDoc, true);
                }
            }
        }

        public void MergeTable(string pName, IEnumerable<object> pList)
        {
            var table = new MailMergeDataTable(pName, pList);
            WDocument.MailMerge.ExecuteGroup(table);
        }

        public void SaveWordDocument(string pDestinationPath)
        {
            MemoryStream mStream = null;
            FileStream fStream = null;
            try
            {
                if (File.Exists(pDestinationPath))
                    File.Delete(pDestinationPath);
                mStream = new MemoryStream();
                fStream = new FileStream(pDestinationPath, FileMode.Create, FileAccess.Write);
                WDocument.Save(mStream, FormatType.Doc);
                mStream.WriteTo(fStream);
            }
            catch (Exception ex)
            {

                throw ex;
            }
            finally
            {
                if (mStream != null)
                {
                    mStream.Close();
                    mStream.Dispose();
                    mStream = null;
                }
                if (fStream != null)
                {
                    fStream.Close();
                    fStream.Dispose();
                    fStream = null;
                }
            }
        }

        public void CloseWordDocument()
        {
            if (WDocument != null)
            {
                WDocument.Close();
                WDocument = null;
            }

        }
    }
}
