﻿using Android.App;
using Android.Widget;
using Android.OS;
using DocIO;
using System.Collections.Generic;
using System;
using System.IO;
using Android.Content;

namespace TestSyncfusionDocIO
{
    [Activity(Label = "TestSyncfusionDocIO", MainLauncher = true, Icon = "@drawable/icon")]
    public class MainActivity : Activity
    {
        private string _sourceFilePath = Path.Combine(RootDirectory, "original-AttestationEntretienGaz.doc");
        private string _destinationFilePath = Path.Combine(RootDirectory, "Result.doc");

        protected override void OnCreate(Bundle bundle)
        {
            base.OnCreate(bundle);
            SetContentView (Resource.Layout.Main);
            FindViewById<Button>(Resource.Id.btTestDocIO).Click += btTestDocIO_Click;
            FindViewById<Button>(Resource.Id.btOpenResult).Click += btOpenResult_Click;
        }

        private static string RootDirectory
        {
            get
            {
                return System.IO.Path.Combine(Android.OS.Environment.ExternalStorageDirectory.Path, "TESTDOC");
            }
        }

        private void btTestDocIO_Click(object sender, System.EventArgs e)
        {
            DocIO.Merger merger = new DocIO.Merger();
            try
            {
                merger.OpenWordDocument(_sourceFilePath);

                // Merge test fields
                var listeChamps = merger.GetFieldNames();
                var listeValeurs = new List<string>();
                for (int i = 0; i < listeChamps.Length; i++)
                {
                    if (listeChamps[i] == "MesureCO")
                        listeValeurs.Add("10");
                    else if (listeChamps[i] == "Gender")
                        listeValeurs.Add("No male");
                    else if (listeChamps[i] == "AddressField")
                        listeValeurs.Add("My custom adresse");
                    else
                        listeValeurs.Add(string.Format("Valeur {0}", listeChamps[i]));
                }
                merger.MergeFields(listeChamps, listeValeurs.ToArray());

                if (File.Exists(_destinationFilePath))
                    File.Delete(_destinationFilePath);

                merger.SaveWordDocument(_destinationFilePath);

            }
            catch (Exception ex)
            {
                new AlertDialog.Builder(this)
                .SetTitle("Erreur fusion")
                .SetMessage(ex.Message)
                .Show();
            }
            finally
            {
                merger.CloseWordDocument();
            }
        }

        private void btOpenResult_Click(object sender, EventArgs e)
        {
            if (!File.Exists(_destinationFilePath))
            {
                Toast.MakeText(this, "Result file does not exists", ToastLength.Short).Show();
                return;
            }

            Java.IO.File file = new Java.IO.File(_destinationFilePath);
            var url = file.AbsolutePath;
            var mimeType = Android.Webkit.MimeTypeMap.Singleton.GetMimeTypeFromExtension(Android.Webkit.MimeTypeMap.GetFileExtensionFromUrl(url));
            var mimeType2 = Java.Net.URLConnection.GuessContentTypeFromName(url);

            Intent intent = new Intent(Intent.ActionView);
            intent.SetFlags(ActivityFlags.NoHistory)
                .SetFlags(ActivityFlags.NewTask)
                .SetFlags(ActivityFlags.GrantReadUriPermission)
                .SetFlags(ActivityFlags.ClearTop)
                .SetDataAndType(Android.Net.Uri.FromFile(new Java.IO.File(_destinationFilePath)), mimeType);
            StartActivity(intent);
        }

    }
}

